// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

#include <sbkpython.h>
#include <shiboken.h>
#include <algorithm>
#include <signature.h>
#include <sbkcontainer.h>
#include <sbkstaticstrings.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysidecleanup.h>
#include <pysideqenum.h>
#include <feature_select.h>
#include <pysidestaticstrings.h>
#include "pyside6_qtnetwork_python.h"

#include <QHash>
#include <QList>
#include <QMap>
#include <QMultiHash>
#include <QMultiMap>
#include <QString>
#include <QtNetwork/qdnslookup.h>
#include <QtNetwork/qhostaddress.h>
#include <QtNetwork/qhstspolicy.h>
#include <QtNetwork/qnetworkcookie.h>
#include <QtNetwork/qnetworkinterface.h>
#include <QtNetwork/qnetworkproxy.h>
#include <QtNetwork/qnetworkrequest.h>
#include <QtNetwork/qocspresponse.h>
#include <QtNetwork/qssl.h>
#include <QtNetwork/qsslcertificate.h>
#include <QtNetwork/qsslcertificateextension.h>
#include <QtNetwork/qsslcipher.h>
#include <QtNetwork/qsslellipticcurve.h>
#include <QtNetwork/qsslerror.h>
#include <qbytearray.h>
#include <qobject.h>
#include <qvariant.h>
#include <utility>


// Current module's type array.
Shiboken::Module::TypeInitStruct *SbkPySide6_QtNetworkTypeStructs = nullptr;
// Backwards compatible structure with identical indexing.
PyTypeObject **SbkPySide6_QtNetworkTypes = nullptr;
// Current module's PyObject pointer.
PyObject *SbkPySide6_QtNetworkModuleObject = nullptr;
// Current module's converter array.
SbkConverter **SbkPySide6_QtNetworkTypeConverters = nullptr;

void cleanTypesAttributes() {
    static PyObject *attrName = Shiboken::PyName::qtStaticMetaObject();
    const int imax = SBK_QtNetwork_IDX_COUNT;
    for (int i = 0; i < imax && SbkPySide6_QtNetworkTypeStructs[i].fullName != nullptr; ++i) {
        auto *pyType = reinterpret_cast<PyObject *>(SbkPySide6_QtNetworkTypeStructs[i].type);
        if (pyType != nullptr && PyObject_HasAttr(pyType, attrName))
            PyObject_SetAttr(pyType, attrName, Py_None);
    }
}

// Global functions ------------------------------------------------------------

static PyMethodDef QtNetwork_methods[] = {
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Classes initialization functions ------------------------------------------------------------
#if QT_CONFIG(ssl)
PyTypeObject *init_QSslPreSharedKeyAuthenticator(PyObject *module);
#endif
#if QT_CONFIG(ssl)
PyTypeObject *init_QSslError(PyObject *module);
#endif
#if QT_CONFIG(ssl)
PyTypeObject *init_QSslEllipticCurve(PyObject *module);
#endif
#if QT_CONFIG(ssl)
PyTypeObject *init_QSslDiffieHellmanParameters(PyObject *module);
#endif
#if QT_CONFIG(ssl)
PyTypeObject *init_QSslConfiguration(PyObject *module);
PyTypeObject *init_QSslConfigurationStaticFields(PyObject *module);
#endif
#if QT_CONFIG(ssl)
PyTypeObject *init_QSslCipher(PyObject *module);
#endif
#if QT_CONFIG(ssl)
PyTypeObject *init_QSslCertificateExtension(PyObject *module);
#endif
PyTypeObject *init_QtNetworkQSsl(PyObject *module);
PyTypeObject *init_QRestReply(PyObject *module);
PyTypeObject *init_QtNetworkQPasswordDigestor(PyObject *module);
#if QT_CONFIG(ssl)
PyTypeObject *init_QOcspResponse(PyObject *module);
#endif
PyTypeObject *init_QNetworkRequestFactory(PyObject *module);
PyTypeObject *init_QNetworkRequest(PyObject *module);
PyTypeObject *init_QNetworkProxyQuery(PyObject *module);
PyTypeObject *init_QNetworkProxyFactory(PyObject *module);
PyTypeObject *init_QNetworkProxy(PyObject *module);
#ifndef QT_NO_NETWORKINTERFACE
PyTypeObject *init_QNetworkInterface(PyObject *module);
#endif
PyTypeObject *init_QNetworkCacheMetaData(PyObject *module);
#ifndef QT_NO_NETWORKINTERFACE
PyTypeObject *init_QNetworkAddressEntry(PyObject *module);
#endif
PyTypeObject *init_QIPv6Address(PyObject *module);
PyTypeObject *init_QHttpPart(PyObject *module);
PyTypeObject *init_QHttpHeaders(PyObject *module);
PyTypeObject *init_QHttp2Configuration(PyObject *module);
PyTypeObject *init_QHttp1Configuration(PyObject *module);
PyTypeObject *init_QHstsPolicy(PyObject *module);
PyTypeObject *init_QHostInfo(PyObject *module);
PyTypeObject *init_QDnsTextRecord(PyObject *module);
PyTypeObject *init_QDnsServiceRecord(PyObject *module);
PyTypeObject *init_QDnsMailExchangeRecord(PyObject *module);
PyTypeObject *init_QDnsHostAddressRecord(PyObject *module);
PyTypeObject *init_QDnsDomainNameRecord(PyObject *module);
PyTypeObject *init_QAuthenticator(PyObject *module);
PyTypeObject *init_QRestAccessManager(PyObject *module);
PyTypeObject *init_QNetworkInformation(PyObject *module);
PyTypeObject *init_QNetworkCookieJar(PyObject *module);
PyTypeObject *init_QNetworkAccessManager(PyObject *module);
PyTypeObject *init_QLocalServer(PyObject *module);
PyTypeObject *init_QHttpMultiPart(PyObject *module);
#if QT_CONFIG(dtls)
PyTypeObject *init_QDtlsClientVerifier(PyObject *module);
#endif
PyTypeObject *init_QDnsLookup(PyObject *module);
PyTypeObject *init_QAbstractNetworkCache(PyObject *module);
PyTypeObject *init_QNetworkDiskCache(PyObject *module);
PyTypeObject *init_QNetworkReply(PyObject *module);
PyTypeObject *init_QLocalSocket(PyObject *module);
PyTypeObject *init_QAbstractSocket(PyObject *module);
PyTypeObject *init_QUdpSocket(PyObject *module);
PyTypeObject *init_QTcpSocket(PyObject *module);
PyTypeObject *init_QHostAddress(PyObject *module);
PyTypeObject *init_QHostAddressStaticFields(PyObject *module);
PyTypeObject *init_QTcpServer(PyObject *module);
#if QT_CONFIG(ssl)
PyTypeObject *init_QSslServer(PyObject *module);
#endif
PyTypeObject *init_QNetworkDatagram(PyObject *module);
#if QT_CONFIG(ssl)
PyTypeObject *init_QSslSocket(PyObject *module);
#endif
PyTypeObject *init_QSslKey(PyObject *module);
#if QT_CONFIG(ssl)
PyTypeObject *init_QSslCertificate(PyObject *module);
#endif
PyTypeObject *init_QNetworkCookie(PyObject *module);
#if QT_CONFIG(dtls)
PyTypeObject *init_QDtlsClientVerifier_GeneratorParameters(PyObject *enclosingClass);
#endif
#if QT_CONFIG(dtls)
PyTypeObject *init_QDtls(PyObject *module);
#endif

// Enum definitions ------------------------------------------------------------
#if QT_CONFIG(ssl)
static void QDtlsError_PythonToCpp_QDtlsError(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QDtlsError>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QDtlsError *>(cppOut) = value;

}
static PythonToCppFunc is_QDtlsError_PythonToCpp_QDtlsError_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDtlsError_IDX])))
        return QDtlsError_PythonToCpp_QDtlsError;
    return {};
}
static PyObject *QDtlsError_CppToPython_QDtlsError(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QDtlsError *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDtlsError_IDX]), castCppIn);

}

#endif
#if QT_CONFIG(ssl)
static void QOcspCertificateStatus_PythonToCpp_QOcspCertificateStatus(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QOcspCertificateStatus>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QOcspCertificateStatus *>(cppOut) = value;

}
static PythonToCppFunc is_QOcspCertificateStatus_PythonToCpp_QOcspCertificateStatus_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QOcspCertificateStatus_IDX])))
        return QOcspCertificateStatus_PythonToCpp_QOcspCertificateStatus;
    return {};
}
static PyObject *QOcspCertificateStatus_CppToPython_QOcspCertificateStatus(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QOcspCertificateStatus *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QOcspCertificateStatus_IDX]), castCppIn);

}

#endif
#if QT_CONFIG(ssl)
static void QOcspRevocationReason_PythonToCpp_QOcspRevocationReason(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QOcspRevocationReason>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QOcspRevocationReason *>(cppOut) = value;

}
static PythonToCppFunc is_QOcspRevocationReason_PythonToCpp_QOcspRevocationReason_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QOcspRevocationReason_IDX])))
        return QOcspRevocationReason_PythonToCpp_QOcspRevocationReason;
    return {};
}
static PyObject *QOcspRevocationReason_CppToPython_QOcspRevocationReason(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QOcspRevocationReason *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QOcspRevocationReason_IDX]), castCppIn);

}

#endif

// Required modules' type and converter arrays.
Shiboken::Module::TypeInitStruct *SbkPySide6_QtCoreTypeStructs;
SbkConverter **SbkPySide6_QtCoreTypeConverters;

// Module initialization ------------------------------------------------------------
// Container Type converters.

// C++ to Python conversion for container type 'QList<int>'.
static PyObject *_QList_int__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<int> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_int_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<int> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        int cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<int>(), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_int__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Conversions::PrimitiveTypeConverter<int>(), pyIn))
        return PySequence_PythonToCpp__QList_int_;
    return {};
}


// Binding for QList<int>

template <>
struct ShibokenContainerValueConverter<int>
{
    static bool checkValue(PyObject *pyArg)
    {
        return PyLong_Check(pyArg);
    }

    static PyObject *convertValueToPython(int cppArg)
    {
        return Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppArg);
    }

    static std::optional<int> convertValueToCpp(PyObject *pyArg)
    {
        Shiboken::Conversions::PythonToCppConversion pythonToCpp;
        if (!(PyLong_Check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg))))) {
            Shiboken::Errors::setWrongContainerType();
            return {};
        }
        int cppArg;
        pythonToCpp(pyArg, &cppArg);
        return cppArg;
    }
};

static PyMethodDef QIntList_methods[] = {
    {"push_back", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::push_back), METH_O, "push_back"},
    {"append", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::push_back), METH_O, "append"},
    {"clear", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::clear), METH_NOARGS, "clear"},
    {"pop_back", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::pop_back), METH_NOARGS, "pop_back"},
    {"removeLast", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::pop_back), METH_NOARGS, "removeLast"},
    {"push_front", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::push_front), METH_O, "push_front"},
    {"prepend", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::push_front), METH_O, "prepend"},
    {"pop_front", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::pop_front), METH_NOARGS, "pop_front"},
    {"removeFirst", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::pop_front), METH_O, "removeFirst"},
    {"reserve", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::reserve), METH_O, "reserve"},
    {"capacity", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::capacity), METH_NOARGS, "capacity"},
    {"data", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::data), METH_NOARGS, "data"},
    {"constData", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::constData), METH_NOARGS, "constData"},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyType_Slot QIntList_slots[] = {
    {Py_tp_init, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<int>>::tpInit)},
    {Py_tp_new, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<int>>::tpNew)},
    {Py_tp_free, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<int>>::tpFree)},
    {Py_tp_dealloc, reinterpret_cast<void *>(Sbk_object_dealloc)},
    {Py_tp_methods, reinterpret_cast<void *>(QIntList_methods)},
    {Py_sq_ass_item, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<int>>::sqSetItem)},
    {Py_sq_length, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<int>>::sqLen)},
    {Py_sq_item, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<int>>::sqGetItem)},
    {0, nullptr}
};

static PyType_Spec QIntList_spec = {
    "2:PySide6.QtNetwork.QIntList",
    sizeof(ShibokenContainer),
    0,
    Py_TPFLAGS_DEFAULT,
    QIntList_slots
};

static inline PyTypeObject *createQIntListType()
{
    auto *result = reinterpret_cast<PyTypeObject *>(SbkType_FromSpec(&QIntList_spec));
    Py_INCREF(Py_True);
    Shiboken::AutoDecRef tpDict(PepType_GetDict(result));
    PyDict_SetItem(tpDict.object(), Shiboken::PyMagicName::opaque_container(), Py_True);
    return result;
}

static PyTypeObject *QIntList_TypeF()
{
    static PyTypeObject *type = createQIntListType();
    return type;
}

extern "C" PyObject *createQIntList(QList<int>* ct)
{
    auto *container = PyObject_New(ShibokenContainer, QIntList_TypeF());
    auto *d = new ShibokenSequenceContainerPrivate<QList<int>>();
    d->m_list = ct;
    container->d = d;
    return reinterpret_cast<PyObject *>(container);
}

extern "C" PyObject *createConstQIntList(const QList<int>* ct)
{
    auto *container = PyObject_New(ShibokenContainer, QIntList_TypeF());
    auto *d = new ShibokenSequenceContainerPrivate<QList<int>>();
    d->m_list = const_cast<QList<int> *>(ct);
    d->m_const = true;
    container->d = d;
    return reinterpret_cast<PyObject *>(container);
}

extern "C" int QIntList_Check(PyObject *pyArg)
{
    return pyArg != nullptr && pyArg != Py_None && pyArg->ob_type == QIntList_TypeF();
}

extern "C" void PythonToCppQIntList(PyObject *pyArg, void *cppOut)
{
    auto *d = ShibokenSequenceContainerPrivate<QList<int>>::get(pyArg);
    *reinterpret_cast<QList<int>**>(cppOut) = d->m_list;
}

extern "C" PythonToCppFunc isQIntListPythonToCppConvertible(PyObject *pyArg)
{
    if (QIntList_Check(pyArg))
        return PythonToCppQIntList;
    return {};
}

// C++ to Python conversion for container type 'QList<QSslCertificate>'.
static PyObject *_QList_QSslCertificate__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QSslCertificate> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslCertificate_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QSslCertificate_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QSslCertificate> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QSslCertificate cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslCertificate_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QSslCertificate__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslCertificate_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QSslCertificate_;
    return {};
}

// C++ to Python conversion for container type 'QList<QByteArray>'.
static PyObject *_QList_QByteArray__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QByteArray> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QByteArray_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QByteArray> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QByteArray cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QByteArray__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QByteArray_;
    return {};
}

// C++ to Python conversion for container type 'QMap<QByteArray,QVariant>'.
static PyObject *_QMap_QByteArray_QVariant__CppToPython_PyDict(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QMap<QByteArray,QVariant> *>(cppIn);
    // TEMPLATE - shiboken_conversion_qmap_to_pydict - START
    PyObject *pyOut = PyDict_New();
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it) {
        const auto &key = it.key();
        const auto &value = it.value();
        PyObject *pyKey = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &key);
        PyObject *pyValue = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &value);
        PyDict_SetItem(pyOut, pyKey, pyValue);
        Py_DECREF(pyKey);
        Py_DECREF(pyValue);
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_qmap_to_pydict - END

}
static void PyDict_PythonToCpp__QMap_QByteArray_QVariant_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QMap<QByteArray,QVariant> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pydict_to_qmap - START
    PyObject *key;
    PyObject *value;
    cppOutRef.clear();
    Py_ssize_t pos = 0;
    while (PyDict_Next(pyIn, &pos, &key, &value)) {
        ::QByteArray cppKey;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), key, &(cppKey));
        ::QVariant cppValue;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], value, &(cppValue));
        cppOutRef.insert(cppKey, cppValue);
    }
    // TEMPLATE - shiboken_conversion_pydict_to_qmap - END

}
static PythonToCppFunc is_PyDict_PythonToCpp__QMap_QByteArray_QVariant__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleDictTypes(PepType_SOTP(reinterpret_cast<PyTypeObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX])))->converter, false, SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], false, pyIn))
        return PyDict_PythonToCpp__QMap_QByteArray_QVariant_;
    return {};
}

// C++ to Python conversion for container type 'QList<QSslCipher>'.
static PyObject *_QList_QSslCipher__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QSslCipher> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslCipher_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QSslCipher_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QSslCipher> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QSslCipher cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslCipher_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QSslCipher__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslCipher_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QSslCipher_;
    return {};
}

// C++ to Python conversion for container type 'QList<QSslEllipticCurve>'.
static PyObject *_QList_QSslEllipticCurve__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QSslEllipticCurve> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslEllipticCurve_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QSslEllipticCurve_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QSslEllipticCurve> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QSslEllipticCurve cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslEllipticCurve_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QSslEllipticCurve__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslEllipticCurve_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QSslEllipticCurve_;
    return {};
}

// C++ to Python conversion for container type 'QList<QNetworkProxy>'.
static PyObject *_QList_QNetworkProxy__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QNetworkProxy> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkProxy_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QNetworkProxy_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QNetworkProxy> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QNetworkProxy cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkProxy_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QNetworkProxy__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkProxy_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QNetworkProxy_;
    return {};
}

// C++ to Python conversion for container type 'QList<QNetworkAddressEntry>'.
static PyObject *_QList_QNetworkAddressEntry__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QNetworkAddressEntry> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkAddressEntry_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QNetworkAddressEntry_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QNetworkAddressEntry> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QNetworkAddressEntry cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkAddressEntry_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QNetworkAddressEntry__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkAddressEntry_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QNetworkAddressEntry_;
    return {};
}

// C++ to Python conversion for container type 'QList<QHostAddress>'.
static PyObject *_QList_QHostAddress__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QHostAddress> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QHostAddress_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QHostAddress> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QHostAddress cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QHostAddress__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QHostAddress_;
    return {};
}

// C++ to Python conversion for container type 'QList<QNetworkInterface>'.
static PyObject *_QList_QNetworkInterface__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QNetworkInterface> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInterface_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QNetworkInterface_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QNetworkInterface> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QNetworkInterface cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInterface_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QNetworkInterface__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInterface_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QNetworkInterface_;
    return {};
}

// C++ to Python conversion for container type 'QHash<QNetworkRequest::Attribute,QVariant>'.
static PyObject *_QHash_QNetworkRequest_Attribute_QVariant__CppToPython_PyDict(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QHash<QNetworkRequest::Attribute,QVariant> *>(cppIn);
    // TEMPLATE - shiboken_conversion_qmap_to_pydict - START
    PyObject *pyOut = PyDict_New();
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it) {
        const auto &key = it.key();
        const auto &value = it.value();
        PyObject *pyKey = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_Attribute_IDX])))->converter, &key);
        PyObject *pyValue = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &value);
        PyDict_SetItem(pyOut, pyKey, pyValue);
        Py_DECREF(pyKey);
        Py_DECREF(pyValue);
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_qmap_to_pydict - END

}
static void PyDict_PythonToCpp__QHash_QNetworkRequest_Attribute_QVariant_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QHash<QNetworkRequest::Attribute,QVariant> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pydict_to_qmap - START
    PyObject *key;
    PyObject *value;
    cppOutRef.clear();
    Py_ssize_t pos = 0;
    while (PyDict_Next(pyIn, &pos, &key, &value)) {
        ::QNetworkRequest::Attribute cppKey{QNetworkRequest::HttpStatusCodeAttribute};
    Shiboken::Conversions::pythonToCppCopy(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_Attribute_IDX])))->converter, key, &(cppKey));
        ::QVariant cppValue;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], value, &(cppValue));
        cppOutRef.insert(cppKey, cppValue);
    }
    // TEMPLATE - shiboken_conversion_pydict_to_qmap - END

}
static PythonToCppFunc is_PyDict_PythonToCpp__QHash_QNetworkRequest_Attribute_QVariant__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleDictTypes(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_Attribute_IDX])))->converter, false, SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], false, pyIn))
        return PyDict_PythonToCpp__QHash_QNetworkRequest_Attribute_QVariant_;
    return {};
}

// C++ to Python conversion for container type 'std::pair<QByteArray,QByteArray>'.
static PyObject *std_pair_QByteArray_QByteArray__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const std::pair<QByteArray,QByteArray> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cpppair_to_pytuple - START
    PyObject *pyOut = PyTuple_New(2);
    PyTuple_SET_ITEM(pyOut, 0, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppInRef.first));
    PyTuple_SET_ITEM(pyOut, 1, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppInRef.second));
    return pyOut;
    // TEMPLATE - shiboken_conversion_cpppair_to_pytuple - END

}
static void PySequence_PythonToCpp_std_pair_QByteArray_QByteArray_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<std::pair<QByteArray,QByteArray> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pysequence_to_cpppair - START
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), PySequence_Fast_GET_ITEM(pyIn, 0), &(cppOutRef.first));
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), PySequence_Fast_GET_ITEM(pyIn, 1), &(cppOutRef.second));
    // TEMPLATE - shiboken_conversion_pysequence_to_cpppair - END

}
static PythonToCppFunc is_PySequence_PythonToCpp_std_pair_QByteArray_QByteArray__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertiblePairTypes(PepType_SOTP(reinterpret_cast<PyTypeObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX])))->converter, false, PepType_SOTP(reinterpret_cast<PyTypeObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX])))->converter, false, pyIn))
        return PySequence_PythonToCpp_std_pair_QByteArray_QByteArray_;
    return {};
}

// C++ to Python conversion for container type 'QList<std::pair< QByteArray,QByteArray>>'.
static PyObject *_QList_std_pair_QByteArray_QByteArray___CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<std::pair< QByteArray,QByteArray>> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_std_pair_QByteArray_QByteArray_IDX], &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_std_pair_QByteArray_QByteArray__(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<std::pair< QByteArray,QByteArray>> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        std::pair<QByteArray,QByteArray> cppItem;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_std_pair_QByteArray_QByteArray_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_std_pair_QByteArray_QByteArray___Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_std_pair_QByteArray_QByteArray_IDX], pyIn))
        return PySequence_PythonToCpp__QList_std_pair_QByteArray_QByteArray__;
    return {};
}

// C++ to Python conversion for container type 'QMultiHash<QByteArray,QByteArray>'.
static PyObject *_QMultiHash_QByteArray_QByteArray__CppToPython_PyDict(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QMultiHash<QByteArray,QByteArray> *>(cppIn);
    // TEMPLATE - shiboken_conversion_qmultihash_to_pydict - START
    PyObject *pyOut = PyDict_New();
        for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ) {
            const auto &key = it.key();
            PyObject *pyKey = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &key);
            auto range = cppInRef.equal_range(key);
            const auto count = Py_ssize_t(std::distance(range.first, range.second));
            PyObject *pyValues = PyList_New(count);
            Py_ssize_t idx = 0;
            for (; it != range.second; ++it, ++idx) {
                const auto &cppItem = it.value();
                PyList_SET_ITEM(pyValues, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppItem));
            }
            PyDict_SetItem(pyOut, pyKey, pyValues);
            Py_DECREF(pyKey);
        }
        return pyOut;
    // TEMPLATE - shiboken_conversion_qmultihash_to_pydict - END

}
static void PyDict_PythonToCpp__QMultiHash_QByteArray_QByteArray_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QMultiHash<QByteArray,QByteArray> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pydict_to_qmultihash - START
    PyObject *key;
        PyObject *values;
        cppOutRef.clear();
        Py_ssize_t pos = 0;
        while (PyDict_Next(pyIn, &pos, &key, &values)) {
            ::QByteArray cppKey;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), key, &(cppKey));
            const Py_ssize_t size = PySequence_Size(values);
            for (Py_ssize_t i = 0; i < size; ++i) {
                Shiboken::AutoDecRef value(PySequence_GetItem(values, i));
                ::QByteArray cppValue;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), value, &(cppValue));
                cppOutRef.insert(cppKey, cppValue);
            }
        }
    // TEMPLATE - shiboken_conversion_pydict_to_qmultihash - END

}
static PythonToCppFunc is_PyDict_PythonToCpp__QMultiHash_QByteArray_QByteArray__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleMultiDictTypes(PepType_SOTP(reinterpret_cast<PyTypeObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX])))->converter, false, PepType_SOTP(reinterpret_cast<PyTypeObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX])))->converter, false, pyIn))
        return PyDict_PythonToCpp__QMultiHash_QByteArray_QByteArray_;
    return {};
}

// C++ to Python conversion for container type 'QMultiMap<QByteArray,QByteArray>'.
static PyObject *_QMultiMap_QByteArray_QByteArray__CppToPython_PyDict(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QMultiMap<QByteArray,QByteArray> *>(cppIn);
    // TEMPLATE - shiboken_conversion_qmultimap_to_pydict - START
    PyObject *pyOut = PyDict_New();
        for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ) {
            const auto &key = it.key();
            PyObject *pyKey = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &key);
            auto upper = cppInRef.upperBound(key);
            const auto count = Py_ssize_t(std::distance(it, upper));
            PyObject *pyValues = PyList_New(count);
            Py_ssize_t idx = 0;
            for (; it != upper; ++it, ++idx) {
                const auto &cppItem = it.value();
                PyList_SET_ITEM(pyValues, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppItem));
            }
            PyDict_SetItem(pyOut, pyKey, pyValues);
            Py_DECREF(pyKey);
        }
        return pyOut;
    // TEMPLATE - shiboken_conversion_qmultimap_to_pydict - END

}
static void PyDict_PythonToCpp__QMultiMap_QByteArray_QByteArray_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QMultiMap<QByteArray,QByteArray> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pydict_to_qmultihash - START
    PyObject *key;
        PyObject *values;
        cppOutRef.clear();
        Py_ssize_t pos = 0;
        while (PyDict_Next(pyIn, &pos, &key, &values)) {
            ::QByteArray cppKey;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), key, &(cppKey));
            const Py_ssize_t size = PySequence_Size(values);
            for (Py_ssize_t i = 0; i < size; ++i) {
                Shiboken::AutoDecRef value(PySequence_GetItem(values, i));
                ::QByteArray cppValue;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), value, &(cppValue));
                cppOutRef.insert(cppKey, cppValue);
            }
        }
    // TEMPLATE - shiboken_conversion_pydict_to_qmultihash - END

}
static PythonToCppFunc is_PyDict_PythonToCpp__QMultiMap_QByteArray_QByteArray__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleMultiDictTypes(PepType_SOTP(reinterpret_cast<PyTypeObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX])))->converter, false, PepType_SOTP(reinterpret_cast<PyTypeObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX])))->converter, false, pyIn))
        return PyDict_PythonToCpp__QMultiMap_QByteArray_QByteArray_;
    return {};
}

// C++ to Python conversion for container type 'QHash<QString,QVariant>'.
static PyObject *_QHash_QString_QVariant__CppToPython_PyDict(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QHash<QString,QVariant> *>(cppIn);
    // TEMPLATE - shiboken_conversion_qmap_to_pydict - START
    PyObject *pyOut = PyDict_New();
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it) {
        const auto &key = it.key();
        const auto &value = it.value();
        PyObject *pyKey = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &key);
        PyObject *pyValue = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &value);
        PyDict_SetItem(pyOut, pyKey, pyValue);
        Py_DECREF(pyKey);
        Py_DECREF(pyValue);
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_qmap_to_pydict - END

}
static void PyDict_PythonToCpp__QHash_QString_QVariant_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QHash<QString,QVariant> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pydict_to_qmap - START
    PyObject *key;
    PyObject *value;
    cppOutRef.clear();
    Py_ssize_t pos = 0;
    while (PyDict_Next(pyIn, &pos, &key, &value)) {
        ::QString cppKey;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], key, &(cppKey));
        ::QVariant cppValue;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], value, &(cppValue));
        cppOutRef.insert(cppKey, cppValue);
    }
    // TEMPLATE - shiboken_conversion_pydict_to_qmap - END

}
static PythonToCppFunc is_PyDict_PythonToCpp__QHash_QString_QVariant__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleDictTypes(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], false, SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], false, pyIn))
        return PyDict_PythonToCpp__QHash_QString_QVariant_;
    return {};
}

// C++ to Python conversion for container type 'QList<QObject*>'.
static PyObject *_QList_QObjectPTR__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QObject*> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QObjectPTR_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QObject*> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QObject* cppItem{nullptr};
    Shiboken::Conversions::pythonToCppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QObjectPTR__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::checkSequenceTypes(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QObjectPTR_;
    return {};
}

// C++ to Python conversion for container type 'QMap<QString,QVariant>'.
static PyObject *_QMap_QString_QVariant__CppToPython_PyDict(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QMap<QString,QVariant> *>(cppIn);
    // TEMPLATE - shiboken_conversion_qmap_to_pydict - START
    PyObject *pyOut = PyDict_New();
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it) {
        const auto &key = it.key();
        const auto &value = it.value();
        PyObject *pyKey = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &key);
        PyObject *pyValue = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &value);
        PyDict_SetItem(pyOut, pyKey, pyValue);
        Py_DECREF(pyKey);
        Py_DECREF(pyValue);
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_qmap_to_pydict - END

}
static void PyDict_PythonToCpp__QMap_QString_QVariant_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QMap<QString,QVariant> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pydict_to_qmap - START
    PyObject *key;
    PyObject *value;
    cppOutRef.clear();
    Py_ssize_t pos = 0;
    while (PyDict_Next(pyIn, &pos, &key, &value)) {
        ::QString cppKey;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], key, &(cppKey));
        ::QVariant cppValue;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], value, &(cppValue));
        cppOutRef.insert(cppKey, cppValue);
    }
    // TEMPLATE - shiboken_conversion_pydict_to_qmap - END

}
static PythonToCppFunc is_PyDict_PythonToCpp__QMap_QString_QVariant__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleDictTypes(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], false, SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], false, pyIn))
        return PyDict_PythonToCpp__QMap_QString_QVariant_;
    return {};
}

// C++ to Python conversion for container type 'QList<QNetworkCookie>'.
static PyObject *_QList_QNetworkCookie__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QNetworkCookie> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCookie_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QNetworkCookie_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QNetworkCookie> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QNetworkCookie cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCookie_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QNetworkCookie__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCookie_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QNetworkCookie_;
    return {};
}

// C++ to Python conversion for container type 'QList<QHstsPolicy>'.
static PyObject *_QList_QHstsPolicy__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QHstsPolicy> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHstsPolicy_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QHstsPolicy_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QHstsPolicy> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QHstsPolicy cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHstsPolicy_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QHstsPolicy__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHstsPolicy_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QHstsPolicy_;
    return {};
}

// C++ to Python conversion for container type 'QList<QSslError>'.
static PyObject *_QList_QSslError__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QSslError> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslError_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QSslError_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QSslError> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QSslError cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslError_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QSslError__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslError_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QSslError_;
    return {};
}

// C++ to Python conversion for container type 'QList<QDnsDomainNameRecord>'.
static PyObject *_QList_QDnsDomainNameRecord__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QDnsDomainNameRecord> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDnsDomainNameRecord_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QDnsDomainNameRecord_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QDnsDomainNameRecord> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QDnsDomainNameRecord cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDnsDomainNameRecord_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QDnsDomainNameRecord__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDnsDomainNameRecord_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QDnsDomainNameRecord_;
    return {};
}

// C++ to Python conversion for container type 'QList<QDnsHostAddressRecord>'.
static PyObject *_QList_QDnsHostAddressRecord__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QDnsHostAddressRecord> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDnsHostAddressRecord_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QDnsHostAddressRecord_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QDnsHostAddressRecord> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QDnsHostAddressRecord cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDnsHostAddressRecord_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QDnsHostAddressRecord__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDnsHostAddressRecord_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QDnsHostAddressRecord_;
    return {};
}

// C++ to Python conversion for container type 'QList<QDnsMailExchangeRecord>'.
static PyObject *_QList_QDnsMailExchangeRecord__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QDnsMailExchangeRecord> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDnsMailExchangeRecord_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QDnsMailExchangeRecord_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QDnsMailExchangeRecord> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QDnsMailExchangeRecord cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDnsMailExchangeRecord_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QDnsMailExchangeRecord__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDnsMailExchangeRecord_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QDnsMailExchangeRecord_;
    return {};
}

// C++ to Python conversion for container type 'QList<QDnsServiceRecord>'.
static PyObject *_QList_QDnsServiceRecord__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QDnsServiceRecord> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDnsServiceRecord_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QDnsServiceRecord_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QDnsServiceRecord> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QDnsServiceRecord cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDnsServiceRecord_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QDnsServiceRecord__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDnsServiceRecord_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QDnsServiceRecord_;
    return {};
}

// C++ to Python conversion for container type 'QList<QDnsTextRecord>'.
static PyObject *_QList_QDnsTextRecord__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QDnsTextRecord> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDnsTextRecord_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QDnsTextRecord_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QDnsTextRecord> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QDnsTextRecord cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDnsTextRecord_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QDnsTextRecord__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDnsTextRecord_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QDnsTextRecord_;
    return {};
}

// C++ to Python conversion for container type 'std::pair<QHostAddress,int>'.
static PyObject *std_pair_QHostAddress_int__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const std::pair<QHostAddress,int> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cpppair_to_pytuple - START
    PyObject *pyOut = PyTuple_New(2);
    PyTuple_SET_ITEM(pyOut, 0, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]), &cppInRef.first));
    PyTuple_SET_ITEM(pyOut, 1, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppInRef.second));
    return pyOut;
    // TEMPLATE - shiboken_conversion_cpppair_to_pytuple - END

}
static void PySequence_PythonToCpp_std_pair_QHostAddress_int_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<std::pair<QHostAddress,int> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pysequence_to_cpppair - START
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]), PySequence_Fast_GET_ITEM(pyIn, 0), &(cppOutRef.first));
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<int>(), PySequence_Fast_GET_ITEM(pyIn, 1), &(cppOutRef.second));
    // TEMPLATE - shiboken_conversion_pysequence_to_cpppair - END

}
static PythonToCppFunc is_PySequence_PythonToCpp_std_pair_QHostAddress_int__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertiblePairTypes(PepType_SOTP(reinterpret_cast<PyTypeObject *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX])))->converter, false, Shiboken::Conversions::PrimitiveTypeConverter<int>(), false, pyIn))
        return PySequence_PythonToCpp_std_pair_QHostAddress_int_;
    return {};
}

// C++ to Python conversion for container type 'QList<QString>'.
static PyObject *_QList_QString__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QString> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QString_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QString> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QString cppItem;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QString__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QString_;
    return {};
}

// C++ to Python conversion for container type 'QList<QSsl::ImplementedClass>'.
static PyObject *_QList_QSsl_ImplementedClass__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QSsl::ImplementedClass> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSsl_ImplementedClass_IDX])))->converter, &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QSsl_ImplementedClass_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QSsl::ImplementedClass> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QSsl::ImplementedClass cppItem{QSsl::ImplementedClass::Key};
    Shiboken::Conversions::pythonToCppCopy(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSsl_ImplementedClass_IDX])))->converter, pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QSsl_ImplementedClass__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSsl_ImplementedClass_IDX])))->converter, pyIn))
        return PySequence_PythonToCpp__QList_QSsl_ImplementedClass_;
    return {};
}

// C++ to Python conversion for container type 'QList<QOcspResponse>'.
static PyObject *_QList_QOcspResponse__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QOcspResponse> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QOcspResponse_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QOcspResponse_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QOcspResponse> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QOcspResponse cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QOcspResponse_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QOcspResponse__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QOcspResponse_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QOcspResponse_;
    return {};
}

// C++ to Python conversion for container type 'QList<QSsl::SupportedFeature>'.
static PyObject *_QList_QSsl_SupportedFeature__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QSsl::SupportedFeature> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSsl_SupportedFeature_IDX])))->converter, &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QSsl_SupportedFeature_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QSsl::SupportedFeature> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QSsl::SupportedFeature cppItem{QSsl::SupportedFeature::CertificateVerification};
    Shiboken::Conversions::pythonToCppCopy(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSsl_SupportedFeature_IDX])))->converter, pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QSsl_SupportedFeature__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSsl_SupportedFeature_IDX])))->converter, pyIn))
        return PySequence_PythonToCpp__QList_QSsl_SupportedFeature_;
    return {};
}

// C++ to Python conversion for container type 'QList<QSsl::SslProtocol>'.
static PyObject *_QList_QSsl_SslProtocol__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QSsl::SslProtocol> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSsl_SslProtocol_IDX])))->converter, &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QSsl_SslProtocol_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QSsl::SslProtocol> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QSsl::SslProtocol cppItem{QSsl::TlsV1_0};
    Shiboken::Conversions::pythonToCppCopy(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSsl_SslProtocol_IDX])))->converter, pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QSsl_SslProtocol__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSsl_SslProtocol_IDX])))->converter, pyIn))
        return PySequence_PythonToCpp__QList_QSsl_SslProtocol_;
    return {};
}

// C++ to Python conversion for container type 'QList<QSslCertificateExtension>'.
static PyObject *_QList_QSslCertificateExtension__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QSslCertificateExtension> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslCertificateExtension_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QSslCertificateExtension_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QSslCertificateExtension> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QSslCertificateExtension cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslCertificateExtension_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QSslCertificateExtension__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslCertificateExtension_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QSslCertificateExtension_;
    return {};
}

// C++ to Python conversion for container type 'QMultiMap<QSsl::AlternativeNameEntryType,QString>'.
static PyObject *_QMultiMap_QSsl_AlternativeNameEntryType_QString__CppToPython_PyDict(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QMultiMap<QSsl::AlternativeNameEntryType,QString> *>(cppIn);
    // TEMPLATE - shiboken_conversion_qmultimap_to_pydict - START
    PyObject *pyOut = PyDict_New();
        for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ) {
            const auto &key = it.key();
            PyObject *pyKey = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSsl_AlternativeNameEntryType_IDX])))->converter, &key);
            auto upper = cppInRef.upperBound(key);
            const auto count = Py_ssize_t(std::distance(it, upper));
            PyObject *pyValues = PyList_New(count);
            Py_ssize_t idx = 0;
            for (; it != upper; ++it, ++idx) {
                const auto &cppItem = it.value();
                PyList_SET_ITEM(pyValues, idx, Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppItem));
            }
            PyDict_SetItem(pyOut, pyKey, pyValues);
            Py_DECREF(pyKey);
        }
        return pyOut;
    // TEMPLATE - shiboken_conversion_qmultimap_to_pydict - END

}
static void PyDict_PythonToCpp__QMultiMap_QSsl_AlternativeNameEntryType_QString_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QMultiMap<QSsl::AlternativeNameEntryType,QString> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pydict_to_qmultihash - START
    PyObject *key;
        PyObject *values;
        cppOutRef.clear();
        Py_ssize_t pos = 0;
        while (PyDict_Next(pyIn, &pos, &key, &values)) {
            ::QSsl::AlternativeNameEntryType cppKey{QSsl::EmailEntry};
    Shiboken::Conversions::pythonToCppCopy(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSsl_AlternativeNameEntryType_IDX])))->converter, key, &(cppKey));
            const Py_ssize_t size = PySequence_Size(values);
            for (Py_ssize_t i = 0; i < size; ++i) {
                Shiboken::AutoDecRef value(PySequence_GetItem(values, i));
                ::QString cppValue;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], value, &(cppValue));
                cppOutRef.insert(cppKey, cppValue);
            }
        }
    // TEMPLATE - shiboken_conversion_pydict_to_qmultihash - END

}
static PythonToCppFunc is_PyDict_PythonToCpp__QMultiMap_QSsl_AlternativeNameEntryType_QString__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleMultiDictTypes(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSsl_AlternativeNameEntryType_IDX])))->converter, false, SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], false, pyIn))
        return PyDict_PythonToCpp__QMultiMap_QSsl_AlternativeNameEntryType_QString_;
    return {};
}

// C++ to Python conversion for container type 'QList<QVariant>'.
static PyObject *_QList_QVariant__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QVariant> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QVariant_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QVariant> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QVariant cppItem;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QVariant__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QVariant_;
    return {};
}


static struct PyModuleDef moduledef = {
    /* m_base     */ PyModuleDef_HEAD_INIT,
    /* m_name     */ "QtNetwork",
    /* m_doc      */ nullptr,
    /* m_size     */ -1,
    /* m_methods  */ QtNetwork_methods,
    /* m_reload   */ nullptr,
    /* m_traverse */ nullptr,
    /* m_clear    */ nullptr,
    /* m_free     */ nullptr
};

// The signatures string for the global functions.
// Multiple signatures have their index "n:" in front.
static const char *QtNetwork_SignatureStrings[] = {
    nullptr}; // Sentinel

static void initInheritance()
{
    auto &bm = Shiboken::BindingManager::instance();
    SBK_UNUSED(bm)
    bm.addClassInheritance(&SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX],
                           &SbkPySide6_QtNetworkTypeStructs[SBK_QRestAccessManager_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX],
                           &SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInformation_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX],
                           &SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCookieJar_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX],
                           &SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkAccessManager_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX],
                           &SbkPySide6_QtNetworkTypeStructs[SBK_QLocalServer_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX],
                           &SbkPySide6_QtNetworkTypeStructs[SBK_QHttpMultiPart_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX],
                           &SbkPySide6_QtNetworkTypeStructs[SBK_QDtlsClientVerifier_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX],
                           &SbkPySide6_QtNetworkTypeStructs[SBK_QDnsLookup_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX],
                           &SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractNetworkCache_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractNetworkCache_IDX],
                           &SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkDiskCache_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtCoreTypeStructs[SBK_QIODevice_IDX],
                           &SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtCoreTypeStructs[SBK_QIODevice_IDX],
                           &SbkPySide6_QtNetworkTypeStructs[SBK_QLocalSocket_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtCoreTypeStructs[SBK_QIODevice_IDX],
                           &SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX],
                           &SbkPySide6_QtNetworkTypeStructs[SBK_QUdpSocket_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX],
                           &SbkPySide6_QtNetworkTypeStructs[SBK_QTcpSocket_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX],
                           &SbkPySide6_QtNetworkTypeStructs[SBK_QTcpServer_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtNetworkTypeStructs[SBK_QTcpServer_IDX],
                           &SbkPySide6_QtNetworkTypeStructs[SBK_QSslServer_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtNetworkTypeStructs[SBK_QTcpSocket_IDX],
                           &SbkPySide6_QtNetworkTypeStructs[SBK_QSslSocket_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX],
                           &SbkPySide6_QtNetworkTypeStructs[SBK_QDtls_IDX]);
}

extern "C" LIBSHIBOKEN_EXPORT PyObject *PyInit_QtNetwork()
{
    if (SbkPySide6_QtNetworkModuleObject != nullptr)
        return SbkPySide6_QtNetworkModuleObject;
    {
        Shiboken::AutoDecRef requiredModule(Shiboken::Module::import("PySide6.QtCore"));
        if (requiredModule.isNull())
            return nullptr;
        SbkPySide6_QtCoreTypeStructs = Shiboken::Module::getTypes(requiredModule);
        SbkPySide6_QtCoreTypeConverters = Shiboken::Module::getTypeConverters(requiredModule);
    }

    // Create an array of wrapper types/names for the current module.
    static Shiboken::Module::TypeInitStruct cppApi[] = {
        {nullptr, "PySide6.QtNetwork.QAbstractNetworkCache"},
        {nullptr, "PySide6.QtNetwork.QAbstractSocket"},
        {nullptr, "PySide6.QtNetwork.QAbstractSocket.BindFlag"},
        {nullptr, "PySide6.QtNetwork.QAbstractSocket.NetworkLayerProtocol"},
        {nullptr, "PySide6.QtNetwork.QAbstractSocket.PauseMode"},
        {nullptr, "PySide6.QtNetwork.QAbstractSocket.SocketError"},
        {nullptr, "PySide6.QtNetwork.QAbstractSocket.SocketOption"},
        {nullptr, "PySide6.QtNetwork.QAbstractSocket.SocketState"},
        {nullptr, "PySide6.QtNetwork.QAbstractSocket.SocketType"},
        {nullptr, "PySide6.QtNetwork.QAuthenticator"},
        {nullptr, "PySide6.QtNetwork.QDnsDomainNameRecord"},
        {nullptr, "PySide6.QtNetwork.QDnsHostAddressRecord"},
        {nullptr, "PySide6.QtNetwork.QDnsLookup"},
        {nullptr, "PySide6.QtNetwork.QDnsLookup.Error"},
        {nullptr, "PySide6.QtNetwork.QDnsLookup.Type"},
        {nullptr, "PySide6.QtNetwork.QDnsMailExchangeRecord"},
        {nullptr, "PySide6.QtNetwork.QDnsServiceRecord"},
        {nullptr, "PySide6.QtNetwork.QDnsTextRecord"},
        {nullptr, "PySide6.QtNetwork.QDtls"},
        {nullptr, "PySide6.QtNetwork.QDtls.HandshakeState"},
        {nullptr, "PySide6.QtNetwork.QDtlsClientVerifier"},
        {nullptr, "PySide6.QtNetwork.QDtlsClientVerifier.GeneratorParameters"},
        {nullptr, "PySide6.QtNetwork.QDtlsError"},
        {nullptr, "PySide6.QtNetwork.QAbstractSocket.BindMode"},
        {nullptr, "PySide6.QtNetwork.QAbstractSocket.PauseModes"},
        {nullptr, "PySide6.QtNetwork.QHostAddress.ConversionMode"},
        {nullptr, "PySide6.QtNetwork.QHstsPolicy.PolicyFlags"},
        {nullptr, "PySide6.QtNetwork.QLocalServer.SocketOptions"},
        {nullptr, "PySide6.QtNetwork.QLocalSocket.SocketOptions"},
        {nullptr, "PySide6.QtNetwork.QNetworkInformation.Features"},
        {nullptr, "PySide6.QtNetwork.QNetworkInterface.InterfaceFlags"},
        {nullptr, "PySide6.QtNetwork.QNetworkProxy.Capabilities"},
        {nullptr, "PySide6.QtNetwork.QSsl.SslOptions"},
        {nullptr, "PySide6.QtNetwork.QHostAddress"},
        {nullptr, "PySide6.QtNetwork.QHostAddress.ConversionModeFlag"},
        {nullptr, "PySide6.QtNetwork.QHostAddress.SpecialAddress"},
        {nullptr, "PySide6.QtNetwork.QHostInfo"},
        {nullptr, "PySide6.QtNetwork.QHostInfo.HostInfoError"},
        {nullptr, "PySide6.QtNetwork.QHstsPolicy"},
        {nullptr, "PySide6.QtNetwork.QHstsPolicy.PolicyFlag"},
        {nullptr, "PySide6.QtNetwork.QHttp1Configuration"},
        {nullptr, "PySide6.QtNetwork.QHttp2Configuration"},
        {nullptr, "PySide6.QtNetwork.QHttpHeaders"},
        {nullptr, "PySide6.QtNetwork.QHttpHeaders.WellKnownHeader"},
        {nullptr, "PySide6.QtNetwork.QHttpMultiPart"},
        {nullptr, "PySide6.QtNetwork.QHttpMultiPart.ContentType"},
        {nullptr, "PySide6.QtNetwork.QHttpPart"},
        {nullptr, "PySide6.QtNetwork.QIPv6Address"},
        {nullptr, "PySide6.QtNetwork.QLocalServer"},
        {nullptr, "PySide6.QtNetwork.QLocalServer.SocketOption"},
        {nullptr, "PySide6.QtNetwork.QLocalSocket"},
        {nullptr, "PySide6.QtNetwork.QLocalSocket.LocalSocketError"},
        {nullptr, "PySide6.QtNetwork.QLocalSocket.LocalSocketState"},
        {nullptr, "PySide6.QtNetwork.QLocalSocket.SocketOption"},
        {nullptr, "PySide6.QtNetwork.QNetworkAccessManager"},
        {nullptr, "PySide6.QtNetwork.QNetworkAccessManager.Operation"},
        {nullptr, "PySide6.QtNetwork.QNetworkAddressEntry"},
        {nullptr, "PySide6.QtNetwork.QNetworkAddressEntry.DnsEligibilityStatus"},
        {nullptr, "PySide6.QtNetwork.QNetworkCacheMetaData"},
        {nullptr, "PySide6.QtNetwork.QNetworkCookie"},
        {nullptr, "PySide6.QtNetwork.QNetworkCookie.RawForm"},
        {nullptr, "PySide6.QtNetwork.QNetworkCookie.SameSite"},
        {nullptr, "PySide6.QtNetwork.QNetworkCookieJar"},
        {nullptr, "PySide6.QtNetwork.QNetworkDatagram"},
        {nullptr, "PySide6.QtNetwork.QNetworkDiskCache"},
        {nullptr, "PySide6.QtNetwork.QNetworkInformation"},
        {nullptr, "PySide6.QtNetwork.QNetworkInformation.Feature"},
        {nullptr, "PySide6.QtNetwork.QNetworkInformation.Reachability"},
        {nullptr, "PySide6.QtNetwork.QNetworkInformation.TransportMedium"},
        {nullptr, "PySide6.QtNetwork.QNetworkInterface"},
        {nullptr, "PySide6.QtNetwork.QNetworkInterface.InterfaceFlag"},
        {nullptr, "PySide6.QtNetwork.QNetworkInterface.InterfaceType"},
        {nullptr, "PySide6.QtNetwork.QNetworkProxy"},
        {nullptr, "PySide6.QtNetwork.QNetworkProxy.Capability"},
        {nullptr, "PySide6.QtNetwork.QNetworkProxy.ProxyType"},
        {nullptr, "PySide6.QtNetwork.QNetworkProxyFactory"},
        {nullptr, "PySide6.QtNetwork.QNetworkProxyQuery"},
        {nullptr, "PySide6.QtNetwork.QNetworkProxyQuery.QueryType"},
        {nullptr, "PySide6.QtNetwork.QNetworkReply"},
        {nullptr, "PySide6.QtNetwork.QNetworkReply.NetworkError"},
        {nullptr, "PySide6.QtNetwork.QNetworkRequest"},
        {nullptr, "PySide6.QtNetwork.QNetworkRequest.Attribute"},
        {nullptr, "PySide6.QtNetwork.QNetworkRequest.CacheLoadControl"},
        {nullptr, "PySide6.QtNetwork.QNetworkRequest.KnownHeaders"},
        {nullptr, "PySide6.QtNetwork.QNetworkRequest.LoadControl"},
        {nullptr, "PySide6.QtNetwork.QNetworkRequest.Priority"},
        {nullptr, "PySide6.QtNetwork.QNetworkRequest.RedirectPolicy"},
        {nullptr, "PySide6.QtNetwork.QNetworkRequest.TransferTimeoutConstant"},
        {nullptr, "PySide6.QtNetwork.QNetworkRequestFactory"},
        {nullptr, "PySide6.QtNetwork.QOcspCertificateStatus"},
        {nullptr, "PySide6.QtNetwork.QOcspResponse"},
        {nullptr, "PySide6.QtNetwork.QOcspRevocationReason"},
        {nullptr, "PySide6.QtNetwork.QPasswordDigestor"},
        {nullptr, "PySide6.QtNetwork.QRestAccessManager"},
        {nullptr, "PySide6.QtNetwork.QRestReply"},
        {nullptr, "PySide6.QtNetwork.QSsl"},
        {nullptr, "PySide6.QtNetwork.QSsl.AlertLevel"},
        {nullptr, "PySide6.QtNetwork.QSsl.AlertType"},
        {nullptr, "PySide6.QtNetwork.QSsl.AlternativeNameEntryType"},
        {nullptr, "PySide6.QtNetwork.QSsl.EncodingFormat"},
        {nullptr, "PySide6.QtNetwork.QSsl.ImplementedClass"},
        {nullptr, "PySide6.QtNetwork.QSsl.KeyAlgorithm"},
        {nullptr, "PySide6.QtNetwork.QSsl.KeyType"},
        {nullptr, "PySide6.QtNetwork.QSsl.SslOption"},
        {nullptr, "PySide6.QtNetwork.QSsl.SslProtocol"},
        {nullptr, "PySide6.QtNetwork.QSsl.SupportedFeature"},
        {nullptr, "PySide6.QtNetwork.QSslCertificate"},
        {nullptr, "PySide6.QtNetwork.QSslCertificate.PatternSyntax"},
        {nullptr, "PySide6.QtNetwork.QSslCertificate.SubjectInfo"},
        {nullptr, "PySide6.QtNetwork.QSslCertificateExtension"},
        {nullptr, "PySide6.QtNetwork.QSslCipher"},
        {nullptr, "PySide6.QtNetwork.QSslConfiguration"},
        {nullptr, "PySide6.QtNetwork.QSslConfiguration.NextProtocolNegotiationStatus"},
        {nullptr, "PySide6.QtNetwork.QSslDiffieHellmanParameters"},
        {nullptr, "PySide6.QtNetwork.QSslDiffieHellmanParameters.Error"},
        {nullptr, "PySide6.QtNetwork.QSslEllipticCurve"},
        {nullptr, "PySide6.QtNetwork.QSslError"},
        {nullptr, "PySide6.QtNetwork.QSslError.SslError"},
        {nullptr, "PySide6.QtNetwork.QSslKey"},
        {nullptr, "PySide6.QtNetwork.QSslPreSharedKeyAuthenticator"},
        {nullptr, "PySide6.QtNetwork.QSslServer"},
        {nullptr, "PySide6.QtNetwork.QSslSocket"},
        {nullptr, "PySide6.QtNetwork.QSslSocket.PeerVerifyMode"},
        {nullptr, "PySide6.QtNetwork.QSslSocket.SslMode"},
        {nullptr, "PySide6.QtNetwork.QTcpServer"},
        {nullptr, "PySide6.QtNetwork.QTcpSocket"},
        {nullptr, "PySide6.QtNetwork.QUdpSocket"},
        {nullptr, nullptr}
    };
    // The new global structure consisting of (type, name) pairs.
    SbkPySide6_QtNetworkTypeStructs = cppApi;
    QT_WARNING_PUSH
    QT_WARNING_DISABLE_DEPRECATED
    // The backward compatible alias with upper case indexes.
    SbkPySide6_QtNetworkTypes = reinterpret_cast<PyTypeObject **>(cppApi);
    QT_WARNING_POP

    // Create an array of primitive type converters for the current module.
    static SbkConverter *sbkConverters[SBK_QtNetwork_CONVERTERS_IDX_COUNT];
    SbkPySide6_QtNetworkTypeConverters = sbkConverters;

    PyObject *module = Shiboken::Module::create("QtNetwork", &moduledef);

    // Make module available from global scope
    SbkPySide6_QtNetworkModuleObject = module;

    // Initialize classes in the type system
#if QT_CONFIG(ssl)
    Shiboken::Module::AddTypeCreationFunction(module, "QSslPreSharedKeyAuthenticator", init_QSslPreSharedKeyAuthenticator);
#endif
#if QT_CONFIG(ssl)
    Shiboken::Module::AddTypeCreationFunction(module, "QSslError", init_QSslError);
#endif
#if QT_CONFIG(ssl)
    Shiboken::Module::AddTypeCreationFunction(module, "QSslEllipticCurve", init_QSslEllipticCurve);
#endif
#if QT_CONFIG(ssl)
    Shiboken::Module::AddTypeCreationFunction(module, "QSslDiffieHellmanParameters", init_QSslDiffieHellmanParameters);
#endif
#if QT_CONFIG(ssl)
    Shiboken::Module::AddTypeCreationFunction(module, "QSslConfiguration", init_QSslConfiguration);
#endif
#if QT_CONFIG(ssl)
    Shiboken::Module::AddTypeCreationFunction(module, "QSslCipher", init_QSslCipher);
#endif
#if QT_CONFIG(ssl)
    Shiboken::Module::AddTypeCreationFunction(module, "QSslCertificateExtension", init_QSslCertificateExtension);
#endif
    Shiboken::Module::AddTypeCreationFunction(module, "QSsl", init_QtNetworkQSsl);
    Shiboken::Module::AddTypeCreationFunction(module, "QRestReply", init_QRestReply);
    Shiboken::Module::AddTypeCreationFunction(module, "QPasswordDigestor", init_QtNetworkQPasswordDigestor);
#if QT_CONFIG(ssl)
    Shiboken::Module::AddTypeCreationFunction(module, "QOcspResponse", init_QOcspResponse);
#endif
    Shiboken::Module::AddTypeCreationFunction(module, "QNetworkRequestFactory", init_QNetworkRequestFactory);
    Shiboken::Module::AddTypeCreationFunction(module, "QNetworkRequest", init_QNetworkRequest);
    Shiboken::Module::AddTypeCreationFunction(module, "QNetworkProxyQuery", init_QNetworkProxyQuery);
    Shiboken::Module::AddTypeCreationFunction(module, "QNetworkProxyFactory", init_QNetworkProxyFactory);
    Shiboken::Module::AddTypeCreationFunction(module, "QNetworkProxy", init_QNetworkProxy);
#ifndef QT_NO_NETWORKINTERFACE
    Shiboken::Module::AddTypeCreationFunction(module, "QNetworkInterface", init_QNetworkInterface);
#endif
    Shiboken::Module::AddTypeCreationFunction(module, "QNetworkCacheMetaData", init_QNetworkCacheMetaData);
#ifndef QT_NO_NETWORKINTERFACE
    Shiboken::Module::AddTypeCreationFunction(module, "QNetworkAddressEntry", init_QNetworkAddressEntry);
#endif
    Shiboken::Module::AddTypeCreationFunction(module, "QIPv6Address", init_QIPv6Address);
    Shiboken::Module::AddTypeCreationFunction(module, "QHttpPart", init_QHttpPart);
    Shiboken::Module::AddTypeCreationFunction(module, "QHttpHeaders", init_QHttpHeaders);
    Shiboken::Module::AddTypeCreationFunction(module, "QHttp2Configuration", init_QHttp2Configuration);
    Shiboken::Module::AddTypeCreationFunction(module, "QHttp1Configuration", init_QHttp1Configuration);
    Shiboken::Module::AddTypeCreationFunction(module, "QHstsPolicy", init_QHstsPolicy);
    Shiboken::Module::AddTypeCreationFunction(module, "QHostInfo", init_QHostInfo);
    Shiboken::Module::AddTypeCreationFunction(module, "QDnsTextRecord", init_QDnsTextRecord);
    Shiboken::Module::AddTypeCreationFunction(module, "QDnsServiceRecord", init_QDnsServiceRecord);
    Shiboken::Module::AddTypeCreationFunction(module, "QDnsMailExchangeRecord", init_QDnsMailExchangeRecord);
    Shiboken::Module::AddTypeCreationFunction(module, "QDnsHostAddressRecord", init_QDnsHostAddressRecord);
    Shiboken::Module::AddTypeCreationFunction(module, "QDnsDomainNameRecord", init_QDnsDomainNameRecord);
    Shiboken::Module::AddTypeCreationFunction(module, "QAuthenticator", init_QAuthenticator);
    Shiboken::Module::AddTypeCreationFunction(module, "QRestAccessManager", init_QRestAccessManager);
    Shiboken::Module::AddTypeCreationFunction(module, "QNetworkInformation", init_QNetworkInformation);
    Shiboken::Module::AddTypeCreationFunction(module, "QNetworkCookieJar", init_QNetworkCookieJar);
    Shiboken::Module::AddTypeCreationFunction(module, "QNetworkAccessManager", init_QNetworkAccessManager);
    Shiboken::Module::AddTypeCreationFunction(module, "QLocalServer", init_QLocalServer);
    Shiboken::Module::AddTypeCreationFunction(module, "QHttpMultiPart", init_QHttpMultiPart);
#if QT_CONFIG(dtls)
    Shiboken::Module::AddTypeCreationFunction(module, "QDtlsClientVerifier", init_QDtlsClientVerifier);
#endif
    Shiboken::Module::AddTypeCreationFunction(module, "QDnsLookup", init_QDnsLookup);
    Shiboken::Module::AddTypeCreationFunction(module, "QAbstractNetworkCache", init_QAbstractNetworkCache);
    Shiboken::Module::AddTypeCreationFunction(module, "QNetworkDiskCache", init_QNetworkDiskCache);
    Shiboken::Module::AddTypeCreationFunction(module, "QNetworkReply", init_QNetworkReply);
    Shiboken::Module::AddTypeCreationFunction(module, "QLocalSocket", init_QLocalSocket);
    Shiboken::Module::AddTypeCreationFunction(module, "QAbstractSocket", init_QAbstractSocket);
    Shiboken::Module::AddTypeCreationFunction(module, "QUdpSocket", init_QUdpSocket);
    Shiboken::Module::AddTypeCreationFunction(module, "QTcpSocket", init_QTcpSocket);
    Shiboken::Module::AddTypeCreationFunction(module, "QHostAddress", init_QHostAddress);
    Shiboken::Module::AddTypeCreationFunction(module, "QTcpServer", init_QTcpServer);
#if QT_CONFIG(ssl)
    Shiboken::Module::AddTypeCreationFunction(module, "QSslServer", init_QSslServer);
#endif
    Shiboken::Module::AddTypeCreationFunction(module, "QNetworkDatagram", init_QNetworkDatagram);
#if QT_CONFIG(ssl)
    Shiboken::Module::AddTypeCreationFunction(module, "QSslSocket", init_QSslSocket);
#endif
    Shiboken::Module::AddTypeCreationFunction(module, "QSslKey", init_QSslKey);
#if QT_CONFIG(ssl)
    Shiboken::Module::AddTypeCreationFunction(module, "QSslCertificate", init_QSslCertificate);
#endif
    Shiboken::Module::AddTypeCreationFunction(module, "QNetworkCookie", init_QNetworkCookie);
#if QT_CONFIG(dtls)
    Shiboken::Module::AddTypeCreationFunction(module, "GeneratorParameters", init_QDtlsClientVerifier_GeneratorParameters, "QDtlsClientVerifier");
#endif
#if QT_CONFIG(dtls)
    Shiboken::Module::AddTypeCreationFunction(module, "QDtls", init_QDtls);
#endif

    // Register converter for type 'QList<int>'.
    SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_int_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_int__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_int_IDX], "QList<int>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_int_IDX],
        PySequence_PythonToCpp__QList_int_,
        is_PySequence_PythonToCpp__QList_int__Convertible);
    Shiboken::Conversions::setPythonToCppPointerFunctions(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_int_IDX],
        PythonToCppQIntList,
        isQIntListPythonToCppConvertible);

    // Register converter for type 'QList<QSslCertificate>'.
    SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QSslCertificate_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QSslCertificate__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QSslCertificate_IDX], "QList<QSslCertificate>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QSslCertificate_IDX],
        PySequence_PythonToCpp__QList_QSslCertificate_,
        is_PySequence_PythonToCpp__QList_QSslCertificate__Convertible);

    // Register converter for type 'QList<QByteArray>'.
    SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QByteArray_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QByteArray__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QByteArray_IDX], "QList<QByteArray>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QByteArray_IDX],
        PySequence_PythonToCpp__QList_QByteArray_,
        is_PySequence_PythonToCpp__QList_QByteArray__Convertible);
    // Register converters for type aliases of QList<QByteArray>'.
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QByteArray_IDX], "QByteArrayList");

    // Register converter for type 'QMap<QByteArray,QVariant>'.
    SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QMap_QByteArray_QVariant_IDX] = Shiboken::Conversions::createConverter(&PyDict_Type, _QMap_QByteArray_QVariant__CppToPython_PyDict);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QMap_QByteArray_QVariant_IDX], "QMap<QByteArray,QVariant>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QMap_QByteArray_QVariant_IDX],
        PyDict_PythonToCpp__QMap_QByteArray_QVariant_,
        is_PyDict_PythonToCpp__QMap_QByteArray_QVariant__Convertible);

    // Register converter for type 'QList<QSslCipher>'.
    SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QSslCipher_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QSslCipher__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QSslCipher_IDX], "QList<QSslCipher>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QSslCipher_IDX],
        PySequence_PythonToCpp__QList_QSslCipher_,
        is_PySequence_PythonToCpp__QList_QSslCipher__Convertible);

    // Register converter for type 'QList<QSslEllipticCurve>'.
    SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QSslEllipticCurve_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QSslEllipticCurve__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QSslEllipticCurve_IDX], "QList<QSslEllipticCurve>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QSslEllipticCurve_IDX],
        PySequence_PythonToCpp__QList_QSslEllipticCurve_,
        is_PySequence_PythonToCpp__QList_QSslEllipticCurve__Convertible);

    // Register converter for type 'QList<QNetworkProxy>'.
    SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QNetworkProxy_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QNetworkProxy__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QNetworkProxy_IDX], "QList<QNetworkProxy>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QNetworkProxy_IDX],
        PySequence_PythonToCpp__QList_QNetworkProxy_,
        is_PySequence_PythonToCpp__QList_QNetworkProxy__Convertible);

    // Register converter for type 'QList<QNetworkAddressEntry>'.
    SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QNetworkAddressEntry_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QNetworkAddressEntry__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QNetworkAddressEntry_IDX], "QList<QNetworkAddressEntry>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QNetworkAddressEntry_IDX],
        PySequence_PythonToCpp__QList_QNetworkAddressEntry_,
        is_PySequence_PythonToCpp__QList_QNetworkAddressEntry__Convertible);

    // Register converter for type 'QList<QHostAddress>'.
    SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QHostAddress_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QHostAddress__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QHostAddress_IDX], "QList<QHostAddress>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QHostAddress_IDX],
        PySequence_PythonToCpp__QList_QHostAddress_,
        is_PySequence_PythonToCpp__QList_QHostAddress__Convertible);

    // Register converter for type 'QList<QNetworkInterface>'.
    SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QNetworkInterface_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QNetworkInterface__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QNetworkInterface_IDX], "QList<QNetworkInterface>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QNetworkInterface_IDX],
        PySequence_PythonToCpp__QList_QNetworkInterface_,
        is_PySequence_PythonToCpp__QList_QNetworkInterface__Convertible);

    // Register converter for type 'QHash<QNetworkRequest::Attribute,QVariant>'.
    SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QHash_QNetworkRequest_Attribute_QVariant_IDX] = Shiboken::Conversions::createConverter(&PyDict_Type, _QHash_QNetworkRequest_Attribute_QVariant__CppToPython_PyDict);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QHash_QNetworkRequest_Attribute_QVariant_IDX], "QHash<QNetworkRequest::Attribute,QVariant>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QHash_QNetworkRequest_Attribute_QVariant_IDX],
        PyDict_PythonToCpp__QHash_QNetworkRequest_Attribute_QVariant_,
        is_PyDict_PythonToCpp__QHash_QNetworkRequest_Attribute_QVariant__Convertible);
    // Register converters for type aliases of QHash<QNetworkRequest::Attribute,QVariant>'.
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QHash_QNetworkRequest_Attribute_QVariant_IDX], "QNetworkCacheMetaData::AttributesMap");

    // Register converter for type 'std::pair<QByteArray,QByteArray>'.
    SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_std_pair_QByteArray_QByteArray_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, std_pair_QByteArray_QByteArray__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_std_pair_QByteArray_QByteArray_IDX], "std::pair<QByteArray,QByteArray>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_std_pair_QByteArray_QByteArray_IDX],
        PySequence_PythonToCpp_std_pair_QByteArray_QByteArray_,
        is_PySequence_PythonToCpp_std_pair_QByteArray_QByteArray__Convertible);
    // Register converters for type aliases of std::pair<QByteArray,QByteArray>'.
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_std_pair_QByteArray_QByteArray_IDX], "QNetworkReply::RawHeaderPair");
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_std_pair_QByteArray_QByteArray_IDX], "QNetworkCacheMetaData::RawHeader");

    // Register converter for type 'QList<std::pair<QByteArray,QByteArray>>'.
    SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_std_pair_QByteArray_QByteArray_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_std_pair_QByteArray_QByteArray___CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_std_pair_QByteArray_QByteArray_IDX], "QList<std::pair<QByteArray,QByteArray>>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_std_pair_QByteArray_QByteArray_IDX],
        PySequence_PythonToCpp__QList_std_pair_QByteArray_QByteArray__,
        is_PySequence_PythonToCpp__QList_std_pair_QByteArray_QByteArray___Convertible);

    // Register converter for type 'QMultiHash<QByteArray,QByteArray>'.
    SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QMultiHash_QByteArray_QByteArray_IDX] = Shiboken::Conversions::createConverter(&PyDict_Type, _QMultiHash_QByteArray_QByteArray__CppToPython_PyDict);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QMultiHash_QByteArray_QByteArray_IDX], "QMultiHash<QByteArray,QByteArray>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QMultiHash_QByteArray_QByteArray_IDX],
        PyDict_PythonToCpp__QMultiHash_QByteArray_QByteArray_,
        is_PyDict_PythonToCpp__QMultiHash_QByteArray_QByteArray__Convertible);

    // Register converter for type 'QMultiMap<QByteArray,QByteArray>'.
    SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QMultiMap_QByteArray_QByteArray_IDX] = Shiboken::Conversions::createConverter(&PyDict_Type, _QMultiMap_QByteArray_QByteArray__CppToPython_PyDict);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QMultiMap_QByteArray_QByteArray_IDX], "QMultiMap<QByteArray,QByteArray>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QMultiMap_QByteArray_QByteArray_IDX],
        PyDict_PythonToCpp__QMultiMap_QByteArray_QByteArray_,
        is_PyDict_PythonToCpp__QMultiMap_QByteArray_QByteArray__Convertible);

    // Register converter for type 'QHash<QString,QVariant>'.
    SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QHash_QString_QVariant_IDX] = Shiboken::Conversions::createConverter(&PyDict_Type, _QHash_QString_QVariant__CppToPython_PyDict);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QHash_QString_QVariant_IDX], "QHash<QString,QVariant>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QHash_QString_QVariant_IDX],
        PyDict_PythonToCpp__QHash_QString_QVariant_,
        is_PyDict_PythonToCpp__QHash_QString_QVariant__Convertible);
    // Register converters for type aliases of QHash<QString,QVariant>'.
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QHash_QString_QVariant_IDX], "QVariantHash");

    // Register converter for type 'QList<QObject*>'.
    SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QObjectPTR_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QObjectPTR__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QObjectPTR_IDX], "QList<QObject*>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QObjectPTR_IDX],
        PySequence_PythonToCpp__QList_QObjectPTR_,
        is_PySequence_PythonToCpp__QList_QObjectPTR__Convertible);
    // Register converters for type aliases of QList<QObject*>'.
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QObjectPTR_IDX], "QObjectList");

    // Register converter for type 'QMap<QString,QVariant>'.
    SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QMap_QString_QVariant_IDX] = Shiboken::Conversions::createConverter(&PyDict_Type, _QMap_QString_QVariant__CppToPython_PyDict);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QMap_QString_QVariant_IDX], "QMap<QString,QVariant>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QMap_QString_QVariant_IDX],
        PyDict_PythonToCpp__QMap_QString_QVariant_,
        is_PyDict_PythonToCpp__QMap_QString_QVariant__Convertible);
    // Register converters for type aliases of QMap<QString,QVariant>'.
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QMap_QString_QVariant_IDX], "QVariantMap");
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QMap_QString_QVariant_IDX], "QSettings::SettingsMap");

    // Register converter for type 'QList<QNetworkCookie>'.
    SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QNetworkCookie_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QNetworkCookie__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QNetworkCookie_IDX], "QList<QNetworkCookie>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QNetworkCookie_IDX],
        PySequence_PythonToCpp__QList_QNetworkCookie_,
        is_PySequence_PythonToCpp__QList_QNetworkCookie__Convertible);

    // Register converter for type 'QList<QHstsPolicy>'.
    SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QHstsPolicy_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QHstsPolicy__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QHstsPolicy_IDX], "QList<QHstsPolicy>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QHstsPolicy_IDX],
        PySequence_PythonToCpp__QList_QHstsPolicy_,
        is_PySequence_PythonToCpp__QList_QHstsPolicy__Convertible);

    // Register converter for type 'QList<QSslError>'.
    SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QSslError_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QSslError__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QSslError_IDX], "QList<QSslError>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QSslError_IDX],
        PySequence_PythonToCpp__QList_QSslError_,
        is_PySequence_PythonToCpp__QList_QSslError__Convertible);

    // Register converter for type 'QList<QDnsDomainNameRecord>'.
    SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QDnsDomainNameRecord_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QDnsDomainNameRecord__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QDnsDomainNameRecord_IDX], "QList<QDnsDomainNameRecord>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QDnsDomainNameRecord_IDX],
        PySequence_PythonToCpp__QList_QDnsDomainNameRecord_,
        is_PySequence_PythonToCpp__QList_QDnsDomainNameRecord__Convertible);

    // Register converter for type 'QList<QDnsHostAddressRecord>'.
    SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QDnsHostAddressRecord_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QDnsHostAddressRecord__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QDnsHostAddressRecord_IDX], "QList<QDnsHostAddressRecord>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QDnsHostAddressRecord_IDX],
        PySequence_PythonToCpp__QList_QDnsHostAddressRecord_,
        is_PySequence_PythonToCpp__QList_QDnsHostAddressRecord__Convertible);

    // Register converter for type 'QList<QDnsMailExchangeRecord>'.
    SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QDnsMailExchangeRecord_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QDnsMailExchangeRecord__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QDnsMailExchangeRecord_IDX], "QList<QDnsMailExchangeRecord>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QDnsMailExchangeRecord_IDX],
        PySequence_PythonToCpp__QList_QDnsMailExchangeRecord_,
        is_PySequence_PythonToCpp__QList_QDnsMailExchangeRecord__Convertible);

    // Register converter for type 'QList<QDnsServiceRecord>'.
    SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QDnsServiceRecord_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QDnsServiceRecord__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QDnsServiceRecord_IDX], "QList<QDnsServiceRecord>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QDnsServiceRecord_IDX],
        PySequence_PythonToCpp__QList_QDnsServiceRecord_,
        is_PySequence_PythonToCpp__QList_QDnsServiceRecord__Convertible);

    // Register converter for type 'QList<QDnsTextRecord>'.
    SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QDnsTextRecord_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QDnsTextRecord__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QDnsTextRecord_IDX], "QList<QDnsTextRecord>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QDnsTextRecord_IDX],
        PySequence_PythonToCpp__QList_QDnsTextRecord_,
        is_PySequence_PythonToCpp__QList_QDnsTextRecord__Convertible);

    // Register converter for type 'std::pair<QHostAddress,int>'.
    SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_std_pair_QHostAddress_int_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, std_pair_QHostAddress_int__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_std_pair_QHostAddress_int_IDX], "std::pair<QHostAddress,int>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_std_pair_QHostAddress_int_IDX],
        PySequence_PythonToCpp_std_pair_QHostAddress_int_,
        is_PySequence_PythonToCpp_std_pair_QHostAddress_int__Convertible);

    // Register converter for type 'QList<QString>'.
    SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QString_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QString__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QString_IDX], "QList<QString>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QString_IDX],
        PySequence_PythonToCpp__QList_QString_,
        is_PySequence_PythonToCpp__QList_QString__Convertible);
    // Register converters for type aliases of QList<QString>'.

    // Register converter for type 'QList<QSsl::ImplementedClass>'.
    SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QSsl_ImplementedClass_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QSsl_ImplementedClass__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QSsl_ImplementedClass_IDX], "QList<QSsl::ImplementedClass>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QSsl_ImplementedClass_IDX],
        PySequence_PythonToCpp__QList_QSsl_ImplementedClass_,
        is_PySequence_PythonToCpp__QList_QSsl_ImplementedClass__Convertible);

    // Register converter for type 'QList<QOcspResponse>'.
    SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QOcspResponse_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QOcspResponse__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QOcspResponse_IDX], "QList<QOcspResponse>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QOcspResponse_IDX],
        PySequence_PythonToCpp__QList_QOcspResponse_,
        is_PySequence_PythonToCpp__QList_QOcspResponse__Convertible);

    // Register converter for type 'QList<QSsl::SupportedFeature>'.
    SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QSsl_SupportedFeature_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QSsl_SupportedFeature__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QSsl_SupportedFeature_IDX], "QList<QSsl::SupportedFeature>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QSsl_SupportedFeature_IDX],
        PySequence_PythonToCpp__QList_QSsl_SupportedFeature_,
        is_PySequence_PythonToCpp__QList_QSsl_SupportedFeature__Convertible);

    // Register converter for type 'QList<QSsl::SslProtocol>'.
    SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QSsl_SslProtocol_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QSsl_SslProtocol__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QSsl_SslProtocol_IDX], "QList<QSsl::SslProtocol>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QSsl_SslProtocol_IDX],
        PySequence_PythonToCpp__QList_QSsl_SslProtocol_,
        is_PySequence_PythonToCpp__QList_QSsl_SslProtocol__Convertible);

    // Register converter for type 'QList<QSslCertificateExtension>'.
    SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QSslCertificateExtension_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QSslCertificateExtension__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QSslCertificateExtension_IDX], "QList<QSslCertificateExtension>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QSslCertificateExtension_IDX],
        PySequence_PythonToCpp__QList_QSslCertificateExtension_,
        is_PySequence_PythonToCpp__QList_QSslCertificateExtension__Convertible);

    // Register converter for type 'QMultiMap<QSsl::AlternativeNameEntryType,QString>'.
    SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QMultiMap_QSsl_AlternativeNameEntryType_QString_IDX] = Shiboken::Conversions::createConverter(&PyDict_Type, _QMultiMap_QSsl_AlternativeNameEntryType_QString__CppToPython_PyDict);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QMultiMap_QSsl_AlternativeNameEntryType_QString_IDX], "QMultiMap<QSsl::AlternativeNameEntryType,QString>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QMultiMap_QSsl_AlternativeNameEntryType_QString_IDX],
        PyDict_PythonToCpp__QMultiMap_QSsl_AlternativeNameEntryType_QString_,
        is_PyDict_PythonToCpp__QMultiMap_QSsl_AlternativeNameEntryType_QString__Convertible);

    // Register converter for type 'QList<QVariant>'.
    SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QVariant_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QVariant__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QVariant_IDX], "QList<QVariant>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QVariant_IDX],
        PySequence_PythonToCpp__QList_QVariant_,
        is_PySequence_PythonToCpp__QList_QVariant__Convertible);
    // Register converters for type aliases of QList<QVariant>'.
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QVariant_IDX], "QVariantList");
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QVariant_IDX], "QVariantList");


    // Opaque container type registration
    PyObject *ob_type{};
    ob_type = reinterpret_cast<PyObject *>(QIntList_TypeF());
    Py_XINCREF(ob_type);
    PyModule_AddObject(module, "QIntList", ob_type);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

#if QT_CONFIG(ssl)
    // Initialization of enum 'QDtlsError'.
    const char *QDtlsError_Initializer[] = {
        "NoError",
        "InvalidInputParameters",
        "InvalidOperation",
        "UnderlyingSocketError",
        "RemoteClosedConnectionError",
        "PeerVerificationError",
        "TlsInitializationError",
        "TlsFatalError",
        "TlsNonFatalError",
        nullptr};
    // "uint8_t" used instead of "unsigned char"
    constexpr uint8_t QDtlsError_InitializerValues[] = {
        uint8_t(QDtlsError::NoError),                     //  0x00  0
        uint8_t(QDtlsError::InvalidInputParameters),      //  0x01  1
        uint8_t(QDtlsError::InvalidOperation),            //  0x02  2
        uint8_t(QDtlsError::UnderlyingSocketError),       //  0x03  3
        uint8_t(QDtlsError::RemoteClosedConnectionError), //  0x04  4
        uint8_t(QDtlsError::PeerVerificationError),       //  0x05  5
        uint8_t(QDtlsError::TlsInitializationError),      //  0x06  6
        uint8_t(QDtlsError::TlsFatalError),               //  0x07  7
        uint8_t(QDtlsError::TlsNonFatalError)             //  0x08  8
        };
    EType = Shiboken::Enum::createPythonEnum(module,
        "2:PySide6.QtNetwork.QDtlsError",
        QDtlsError_Initializer, QDtlsError_InitializerValues);
    SbkPySide6_QtNetworkTypeStructs[SBK_QDtlsError_IDX].type = EType;
    // Register converter for enum 'QDtlsError'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QDtlsError_CppToPython_QDtlsError);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QDtlsError_PythonToCpp_QDtlsError,
            is_QDtlsError_PythonToCpp_QDtlsError_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QDtlsError");
    }
    // End of 'QDtlsError' enum.

#endif
#if QT_CONFIG(ssl)
    // Initialization of enum 'QOcspCertificateStatus'.
    const char *QOcspCertificateStatus_Initializer[] = {
        "Good",
        "Revoked",
        "Unknown",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t QOcspCertificateStatus_InitializerValues[] = {
        int8_t(QOcspCertificateStatus::Good),    //  0x00  0
        int8_t(QOcspCertificateStatus::Revoked), //  0x01  1
        int8_t(QOcspCertificateStatus::Unknown)  //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(module,
        "2:PySide6.QtNetwork.QOcspCertificateStatus",
        QOcspCertificateStatus_Initializer, QOcspCertificateStatus_InitializerValues);
    SbkPySide6_QtNetworkTypeStructs[SBK_QOcspCertificateStatus_IDX].type = EType;
    // Register converter for enum 'QOcspCertificateStatus'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QOcspCertificateStatus_CppToPython_QOcspCertificateStatus);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QOcspCertificateStatus_PythonToCpp_QOcspCertificateStatus,
            is_QOcspCertificateStatus_PythonToCpp_QOcspCertificateStatus_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QOcspCertificateStatus");
    }
    // End of 'QOcspCertificateStatus' enum.

#endif
#if QT_CONFIG(ssl)
    // Initialization of enum 'QOcspRevocationReason'.
    const char *QOcspRevocationReason_Initializer[] = {
        "None_",
        "Unspecified",
        "KeyCompromise",
        "CACompromise",
        "AffiliationChanged",
        "Superseded",
        "CessationOfOperation",
        "CertificateHold",
        "RemoveFromCRL",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t QOcspRevocationReason_InitializerValues[] = {
        int8_t(QOcspRevocationReason::None),                 // -0x01 -1
        int8_t(QOcspRevocationReason::Unspecified),          //  0x00  0
        int8_t(QOcspRevocationReason::KeyCompromise),        //  0x01  1
        int8_t(QOcspRevocationReason::CACompromise),         //  0x02  2
        int8_t(QOcspRevocationReason::AffiliationChanged),   //  0x03  3
        int8_t(QOcspRevocationReason::Superseded),           //  0x04  4
        int8_t(QOcspRevocationReason::CessationOfOperation), //  0x05  5
        int8_t(QOcspRevocationReason::CertificateHold),      //  0x06  6
        int8_t(QOcspRevocationReason::RemoveFromCRL)         //  0x07  7
        };
    EType = Shiboken::Enum::createPythonEnum(module,
        "2:PySide6.QtNetwork.QOcspRevocationReason",
        QOcspRevocationReason_Initializer, QOcspRevocationReason_InitializerValues);
    SbkPySide6_QtNetworkTypeStructs[SBK_QOcspRevocationReason_IDX].type = EType;
    // Register converter for enum 'QOcspRevocationReason'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QOcspRevocationReason_CppToPython_QOcspRevocationReason);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QOcspRevocationReason_PythonToCpp_QOcspRevocationReason,
            is_QOcspRevocationReason_PythonToCpp_QOcspRevocationReason_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QOcspRevocationReason");
    }
    // End of 'QOcspRevocationReason' enum.

#endif
    // Register primitive types converters.
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__blkcnt64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__blkcnt_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__blksize_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<char>(), "__caddr_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__clock_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__clockid_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__compar_d_fn_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__compar_fn_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__daddr_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__dev_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__fsblkcnt64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__fsblkcnt_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__fsfilcnt64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__fsfilcnt_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__fsword_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__gid_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__id_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__ino64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__ino_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<short>(), "__int16_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__int32_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__int64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<signed char>(), "__int8_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<short>(), "__int_least16_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__int_least32_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__int_least64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<signed char>(), "__int_least8_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__intmax_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__intptr_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__key_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__loff_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__mode_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__nlink_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__off64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__off_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__pid_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__quad_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__rlim64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__rlim_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__sig_atomic_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__socklen_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__ssize_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__suseconds64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__suseconds_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__syscall_slong_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__syscall_ulong_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__time_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "__u_char");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__u_int");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__u_long");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__u_quad_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), "__u_short");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__uid_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), "__uint16_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__uint32_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__uint64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "__uint8_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), "__uint_least16_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__uint_least32_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__uint_least64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "__uint_least8_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__uintmax_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__useconds_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "blkcnt64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "blkcnt_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "blksize_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<char>(), "caddr_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "comparison_fn_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "daddr_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "dev_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "fsblkcnt64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "fsblkcnt_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "fsfilcnt64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "fsfilcnt_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "gid_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "id_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "ino64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "ino_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "int_fast16_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "int_fast32_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "int_fast64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<signed char>(), "int_fast8_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "intmax_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "key_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "loff_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "mode_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "nlink_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "off64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "off_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "pid_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), "qInternalCallback");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "quad_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "register_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "ssize_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "suseconds_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "u_char");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "u_int");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), "u_int16_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "u_int32_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "u_int64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "u_int8_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "u_long");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "u_quad_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), "u_short");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "uid_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "uint_fast16_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "uint_fast32_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "uint_fast64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "uint_fast8_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "uintmax_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "useconds_t");

    Shiboken::Module::registerTypes(module, SbkPySide6_QtNetworkTypeStructs);
    Shiboken::Module::registerTypeConverters(module, SbkPySide6_QtNetworkTypeConverters);

    // Static field initialization
#if QT_CONFIG(ssl)
    init_QSslConfigurationStaticFields(module);
#endif
    init_QHostAddressStaticFields(module);

    initInheritance();

    if (Shiboken::Errors::occurred() != nullptr) {
        PyErr_Print();
        Py_FatalError("can't initialize module QtNetwork");
    }
#if QT_CONFIG(ssl)
    qRegisterMetaType< ::QDtlsError >("QDtlsError");
#endif
#if QT_CONFIG(ssl)
    qRegisterMetaType< ::QOcspCertificateStatus >("QOcspCertificateStatus");
#endif
#if QT_CONFIG(ssl)
    qRegisterMetaType< ::QOcspRevocationReason >("QOcspRevocationReason");
#endif
    PySide::registerCleanupFunction(cleanTypesAttributes);

    FinishSignatureInitialization(module, QtNetwork_SignatureStrings);

    return module;
}
